==> indy-node-dev-1.6.708.tar.gz: indy-node-dev-1.6.708/indy_node/server/validator_info_tool.py <==
import importlib

from indy_node.__metadata__ import __version__ as node_pgk_version
from plenum.server.validator_info_tool import none_on_fail, \
    ValidatorNodeInfoTool as PlenumValidatorNodeInfoTool
from plenum.common.constants import POOL_LEDGER_ID, DOMAIN_LEDGER_ID, CONFIG_LEDGER_ID


class ValidatorNodeInfoTool(PlenumValidatorNodeInfoTool):

    @property
    def info(self):
        info = super().info
        if 'Node_info' in info:
            if 'Metrics' in info['Node_info']:
                info['Node_info']['Metrics']['transaction-count'].update(config=self.__config_ledger_size)
                std_ledgers = [POOL_LEDGER_ID, DOMAIN_LEDGER_ID, CONFIG_LEDGER_ID]
                other_ledgers = {}
                for idx, linfo in self._node.ledgerManager.ledgerRegistry.items():
                    if linfo.id in std_ledgers:
                        continue
                    other_ledgers[linfo.id] = linfo.ledger.size
                info['Node_info']['Metrics']['transaction-count'].update(other_ledgers)

        return info

    @property
    @none_on_fail
    def software_info(self):
        info = super().software_info
        if 'Software' in info:
            info['Software'].update({'indy-node': self.__node_pkg_version})
            try:
                pkg = importlib.import_module(self._config.UPGRADE_ENTRY)
                info['Software'].update({self._config.UPGRADE_ENTRY: pkg.__version__})
            except Exception:
                pass
        return info

    @property
    @none_on_fail
    def __config_ledger_size(self):
        return self._node.configLedger.size

    @property
    @none_on_fail
    def __node_pkg_version(self):
        return node_pgk_version

==> indy-node-dev-1.6.758.tar.gz: indy-node-dev-1.6.758/indy_node/server/validator_info_tool.py <==
import importlib
import time
import os

from indy_node.__metadata__ import __version__ as node_pgk_version
from plenum.server.validator_info_tool import none_on_fail, \
    ValidatorNodeInfoTool as PlenumValidatorNodeInfoTool
from plenum.common.constants import POOL_LEDGER_ID, DOMAIN_LEDGER_ID, CONFIG_LEDGER_ID


class ValidatorNodeInfoTool(PlenumValidatorNodeInfoTool):

    @property
    def info(self):
        info = super().info
        ts_str = "{}".format(time.strftime(
            "%A, %B %{0}d, %Y %{0}I:%M:%S %p %z".format('#' if os.name == 'nt' else '-'),
            time.localtime(info["timestamp"])))
        info.update({"Update_time": ts_str})
        if 'Node_info' in info:
            if 'Metrics' in info['Node_info']:
                std_ledgers = [POOL_LEDGER_ID, DOMAIN_LEDGER_ID, CONFIG_LEDGER_ID]
                other_ledgers = {}
                for idx, linfo in self._node.ledgerManager.ledgerRegistry.items():
                    if linfo.id in std_ledgers:
                        continue
                    other_ledgers[linfo.id] = linfo.ledger.size
                info['Node_info']['Metrics']['transaction-count'].update(other_ledgers)

        return info

    @none_on_fail
    def _generate_software_info(self):
        sfv = super()._generate_software_info()
        sfv['Software'].update({'indy-node': self.__node_pkg_version})
        sfv['Software'].update({'sovrin': "unknown"})
        try:
            pkg = importlib.import_module(self._config.UPGRADE_ENTRY)
            sfv['Software'].update({self._config.UPGRADE_ENTRY: pkg.__version__})
        except Exception:
            pass

        return sfv

    @property
    @none_on_fail
    def __node_pkg_version(self):
        return node_pgk_version
